@@ -1,4 +1,4 @@
-from logging import DEBUG, INFO, Formatter, LogRecord, StreamHandler
+from logging import DEBUG, INFO, WARNING, Formatter, LogRecord, StreamHandler
 
 try:
     import DomoticzEx
@@ -12,13 +12,14 @@ class DomoticzHandler(StreamHandler):
     def __init__(self):
         super().__init__()
         self.setFormatter(Formatter("%(levelname)s: %(name)s: %(message)s"))
-        self.setLevel(DEBUG)
 
     def emit(self, record: LogRecord) -> None:
         msg = self.format(record)
-        if record.levelno <= DEBUG:
+        if record.levelno < DEBUG:
             DomoticzEx.Debug(msg)
-        elif record.levelno <= INFO:
+        elif record.levelno < INFO:
             DomoticzEx.Log(msg)
+        elif record.levelno < WARNING:
+            DomoticzEx.Status(msg)
         else:
             DomoticzEx.Error(msg)
